@@ -59,7 +59,7 @@ void ResourceManager::loadCourseResources()
     // register skeleton resources
     QDir skeletonRepository = QDir(Settings::courseRepositoryPath());
     skeletonRepository.setFilter(QDir::Files | QDir::Hidden);
-    if (!skeletonRepository.cd("skeletons")) {
+    if (!skeletonRepository.cd(QStringLiteral("skeletons"))) {
         qCritical() << "There is no subdirectory \"skeletons\" in directory " << skeletonRepository.path()
             << " cannot load skeletons.";
     } else {
@@ -73,7 +73,7 @@ void ResourceManager::loadCourseResources()
 
     // register contributor course files
     QDir courseRepository = QDir(Settings::courseRepositoryPath());
-    if (!courseRepository.cd("courses")) {
+    if (!courseRepository.cd(QStringLiteral("courses"))) {
         qCritical() << "There is no subdirectory \"courses\" in directory " << courseRepository.path()
             << " cannot load courses.";
     } else {
@@ -93,7 +93,7 @@ void ResourceManager::loadCourseResources()
                 QDir courseLangDir = QDir(langInfo.absoluteFilePath());
                 courseLangDir.setFilter(QDir::Files);
                 QStringList nameFilters;
-                nameFilters.append("*.xml");
+                nameFilters.append(QStringLiteral("*.xml"));
                 QFileInfoList courses = courseLangDir.entryInfoList(nameFilters);
 
                 // find and add course files
@@ -117,7 +117,7 @@ void ResourceManager::loadCourseResources()
             QFileInfoList list = dir.entryInfoList();
             for (int i = 0; i < list.size(); ++i) {
                 QFileInfo fileInfo = list.at(i);
-                if (fileInfo.completeSuffix() != "xml") {
+                if (fileInfo.completeSuffix() != QLatin1String("xml")) {
                     continue;
                 }
                 addCourse(QUrl::fromLocalFile(fileInfo.absoluteFilePath()));
@@ -141,7 +141,7 @@ void ResourceManager::loadLanguageResources()
         QFileInfoList list = dir.entryInfoList();
         for (int i = 0; i < list.size(); ++i) {
             QFileInfo fileInfo = list.at(i);
-            if (fileInfo.completeSuffix() != "xml") {
+            if (fileInfo.completeSuffix() != QLatin1String("xml")) {
                 continue;
             }
             addLanguage(QUrl::fromLocalFile(fileInfo.absoluteFilePath()));
@@ -408,9 +408,9 @@ void ResourceManager::removeCourse(Course *course)
 Course * ResourceManager::createCourse(Language *language, Skeleton *skeleton)
 {
     // set path
-    QString path = QString("%1/%2/%3/%4/%4.xml")
+    QString path = QStringLiteral("%1/%2/%3/%4/%4.xml")
         .arg(Settings::courseRepositoryPath())
-        .arg("courses")
+        .arg(QStringLiteral("courses"))
         .arg(skeleton->id())
         .arg(language->id());
 
